@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 use warnings;
 use strict;
@@ -137,6 +137,35 @@ sub get_attr {
     return $self->get_vertex_attribute($v, $attr) || 0;
 }
 
+
+sub span {
+    my ($self, $attr) = @_;
+
+    my $mass = {};
+    for my $vertex ( $self->vertices ) {
+        $mass->{$vertex} = $self->get_attr($vertex, $attr);
+    }
+
+    my ($smallest, $biggest);
+    for my $vertex ( keys %$mass ) {
+        my $current = $mass->{$vertex};
+        if ( !defined $smallest || $smallest > $current ) {
+            $smallest = $current;
+        }
+        if ( !defined $biggest || $biggest < $current ) {
+            $biggest = $current;
+        }
+    }
+
+    my ($lightest, $heaviest) = ([], []);
+    for my $vertex ( keys %$mass ) {
+        push @$lightest, $vertex if $mass->{$vertex} == $smallest;
+        push @$heaviest, $vertex if $mass->{$vertex} == $biggest;
+    }
+
+    return $lightest, $heaviest;
+}
+
 1;
 
 __END__
@@ -151,7 +180,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.54
+version 0.55
 
 =head1 SYNOPSIS
 
@@ -175,6 +204,8 @@ version 0.54
     }
  }
 
+ my ($heaviest, $lightest) = $gw->span();
+
  my $gw = Graph::Weighted->new();
  my $attr = 'probability';
  $gw->populate(
@@ -205,7 +236,7 @@ as documented, but with the addition of custom weighting.
 
 =head2 new()
 
-  my $g = Graph::Weighted->new;
+  my $gw = Graph::Weighted->new;
 
 Return a new C<Graph::Weighted> object.
 
@@ -213,10 +244,10 @@ Please see L<Graph> for the possible constructor arguments.
 
 =head2 populate()
 
-  $g->populate($matrix);
-  $g->populate(\@vectors);
-  $g->populate(\@vectors, $attribute);
-  $g->populate(\%data_points, $attribute);
+  $gw->populate($matrix);
+  $gw->populate(\@vectors);
+  $gw->populate(\@vectors, $attribute);
+  $gw->populate(\%data_points, $attribute);
 
 Populate a graph with weighted nodes.
 
@@ -226,7 +257,7 @@ values.  The C<attribute> is an optional string name, with the default "weight."
 
 Examples of C<data> in array reference form:
 
-  []      No edges.
+  []      1 vertex with no edges.
   [0]     1 vertex and 1 edge to node 0 having weight of 0.
   [1]     1 vertex and 1 edge to node 0 weight 1.
   [0,1]   2 vertices and 2 edges having edge weights 0,1 and vertex weight 1.
@@ -237,8 +268,8 @@ the overall dimension.
 
 =head2 get_weight()
 
-  $w = $g->get_weight($vertex);
-  $w = $g->get_weight([$vertex, $neighbor]);
+  $w = $gw->get_weight($vertex);
+  $w = $gw->get_weight([$vertex, $neighbor]);
 
 Return the weight for the vertex or edge.
 
@@ -247,16 +278,21 @@ If no value is found, zero is returned.
 
 =head2 get_attr()
 
-  $w = $g->get_attr($vertex, $attribute);
-  $w = $g->get_attr(\@edge, $attribute);
+  $w = $gw->get_attr($vertex, $attribute);
+  $w = $gw->get_attr(\@edge, $attribute);
 
 Return the named attribute value for the vertex or edge.
 
+=head2 span()
+
+ my ($lightest, $heaviest) = $gw->span();
+ my ($lightest, $heaviest) = $gw->span($attr);
+
+Return the span of lightest to heaviest vertices.
+
 =head1 TO DO
 
-Find the heaviest and lightest nodes and edges.
-
-Find the total weight beneath and above a node.
+Find the total weight beneath a node.
 
 =head1 SEE ALSO
 
